@@ -75,16 +75,25 @@ class HeaderToLabelMiddleware(object):
 
     def process_response(self, request, response):
         headers = Utils.obfuscate_headers(Utils.get_all_headers(request))
+        status_code = 500
+        if hasattr(response, "status_code"):
+            status_code = response.status_code
+
+        if hasattr(response, "content"):
+            content = response.content.decode("UTF-8")
+        else:
+            content = str(response)
+
         log_entry = dict(
             type=self._RESPONSE,
             request_start_time_ms=self._request_start_time,
             request_end_time_ms=Utils.get_time_in_milliseconds(),
             method=request.method,
             body=Utils.obfuscate_body(Utils.adjust_string_length(self._initial_http_body,
-                                            getattr(settings, MAX_REQUEST_RESPONSE_SIZE)) if response.status_code < 400 else Utils.obfuscate_body(self._initial_http_body.decode("UTF-8"))),
-            status_code=response.status_code,
-            response=Utils.obfuscate_response(Utils.adjust_string_length(response.content,
-                                                settings.MAX_REQUEST_RESPONSE_SIZE) if response.status_code < 400 else Utils.obfuscate_body(response.content.decode("UTF-8"))),
+                                            getattr(settings, MAX_REQUEST_RESPONSE_SIZE)) if status_code < 400 else Utils.obfuscate_body(self._initial_http_body.decode("UTF-8"))),
+            status_code=status_code,
+            response=Utils.obfuscate_response(Utils.adjust_string_length(content,
+                                                settings.MAX_REQUEST_RESPONSE_SIZE) if status_code < 400 else Utils.obfuscate_body(content)),
             url=Utils.obfuscate_url(request.build_absolute_uri())
         )
         log_entry.update(headers)
@@ -93,7 +102,7 @@ class HeaderToLabelMiddleware(object):
             type=self._RESPONSE,
             request_start_time_ms=self._request_start_time,
             request_end_time_ms=Utils.get_time_in_milliseconds(),
-            status_code=response.status_code,
+            status_code=status_code,
             method=request.method,
             url=Utils.obfuscate_url(request.build_absolute_uri())
         )
@@ -105,7 +114,7 @@ class HeaderToLabelMiddleware(object):
             log_entry[label] = getattr(request, label)
             log_entry_info[label] = getattr(request, label)
 
-        if response.status_code < 400:
+        if status_code < 400:
             logger.debug(
                 '', extra=log_entry
             )
